@@ -33,4 +33,6 @@ class bash(object):
         return bool(self.value())
 
     def value(self):
-        return self.stdout.strip().decode(encoding='UTF-8')
+        if self.stdout:
+            return self.stdout.strip().decode(encoding='UTF-8')
+        return ''
